#include <iostream>
#include <complex>
#include <list>
using namespace std;

const double EPS = 1e-6;

#define sz(a)						int(a.size())
#define EQ(a, b)					(abs(a - b) < EPS)
#define X							real()
#define Y							imag()

typedef complex<double> point;

const int MAX_N = 1001;
const point I(112512112235232222351555.12412415566511, 1150129171721491352523221.129128198);

int A, C, V, T;
point a[MAX_N], convex[MAX_N], v[MAX_N], t[MAX_N];
list<int> l;
list<int>::iterator now, prev, next;
double ans;

void Read()
{
int x, y;
	
	while(1)
	{
		string line = "";
		
		while(1)
		{
			char c;
			
			c = getc(stdin);
			
			if(c == '\n') break;
			
			line += c;
		}
		
		if(line == "") break;
		
		stringstream ss(line);
		
		ss >> x >> y;
		
		a[A ++] = point(x, y);
	}
	
	while(cin >> x >> y)
	{
		convex[C ++] = point(x, y);
	}
}

double dot(const point &_a, const point &_b)
{
	return real(conj(_a) * _b);
}

double cross(const point &_a, const point &_b)
{
	return imag(conj(_a) * _b);
}

double area2(const point &_a, const point &_b, const point &_c)
{
	return cross(_b - _a, _c - _a);
}

double area(const point &_a, const point &_b, const point &_c)
{
	return abs(cross(_b - _a, _c - _a) * 0.5);
}

int sign(const double &_a)
{
	if(EQ(_a, 0.0)) return 0;
	if(0.0 < _a) return + 1;
	if(_a < 0.0) return - 1;
}

bool intersects_segments(const point &_a, const point &_b, const point &_p, const point &_q)
{
	if(0 <= sign(area2(_a, _b, _p)) * sign(area2(_a, _b, _q))) return false;
	
	if(0 <= sign(area2(_p, _q, _a)) * sign(area2(_p, _q, _b))) return false;
	
	return true;
}

point intersect(const point &_a, const point &_b, const point &_p, const point &_q)
{
	double d1 = area2(_a, _b, _p);
	double d2 = area2(_a, _b, _q);
	
	return (d1 * _q - d2 * _p) / (d1 - d2);
}

bool is_inside(int idx1, int idx2)
{
int ret = 0;
	
	if(sz(l) == 3) return true;
	
	for(int i = 0; i < A; i ++)
	{
		if(intersects_segments(a[idx1], a[idx2], a[i], a[(i + 1) % A]))
		{
			return false;
		}
	}
	
	point M = (a[idx1] + a[idx2]) * 0.5;
	
	for(int i = 0; i < A; i ++)
	{
		if(intersects_segments(M, I, a[i], a[(i + 1) % A]))
		{
			ret ++;
		}
	}
	
	if(ret & 1) return true;
	
	return false;
}

bool inside(const point &_a)
{
int i;
	
	for(i = 0; i < C; i ++)
	{
		if(area2(convex[i], convex[(i + 1) % C], _a) < 0.0) break;
	}
	
	if(i == C) return true;
	
	for(i = 0; i < C; i ++)
	{
		if(0.0 < area2(convex[i], convex[(i + 1) % C], _a)) break;
	}
	
	if(i == C) return true;
	
	return false;
}

double dist(const point &_a)
{
	return sqrt(dot(_a, _a));
}

bool online(const point &_a, const point &_b, const point &_c)
{
	if(EQ(arg(_b - _a), arg(_c - _a)))
	{
		if(EQ((dist(_a - _b) + dist(_b - _c)), dist(_a - _c))) return true;
		
		return false;
	}
	
	return false;
}

bool cmp_x(const point &_a, const point &_b)
{
	if(!EQ(_a.X, _b.X)) return (_a.X < _b.X);
	if(!EQ(_a.Y, _b.Y)) return (_b.Y < _a.Y);
	return false;
}

void make_convex()
{
	T = 0;
	sort(v, v + V, cmp_x);
	
	for(int i = 0; i < V; i ++)
	{
		while(2 <= T && 0 <= sign(area2(t[T - 2], t[T - 1], v[i])))
		{
			T --;
		}
		
		t[T ++] = v[i];
	}
	
	for(int i = V - 1; 0 <= i; i --)
	{
		while(2 <= T && 0 <= sign(area2(t[T - 2], t[T - 1], v[i])) && v[i] != t[T - 2])
		{
			T --;
		}
		
		if(v[i] != t[T - 2]) t[T ++] = v[i];
	}
	
	V = T;
	
	for(int i = 0; i < T; i ++)
	{
		v[i] = t[i];
	}
}

double overlap(const point &_a, const point &_b, const point &_c)
{
double ret = 0.0;
	
	V = 0;
	if(inside(_a)) v[V ++] = _a;
	if(inside(_b)) v[V ++] = _b;
	if(inside(_c)) v[V ++] = _c;
	
	if(V == 3) return area(_a, _b, _c);
	
	for(int i = 0; i < C; i ++)
	{
		if(0 < sign(area2(_a, _b, convex[i])) &&
			0 < sign(area2(_b, _c, convex[i])) &&
				0 < sign(area2(_c, _a, convex[i])))
		{
			v[V ++] = convex[i];
		}
		
		if(sign(area2(_a, _b, convex[i])) < 0 &&
			sign(area2(_b, _c, convex[i])) < 0 &&
				sign(area2(_c, _a, convex[i])) < 0)
		{
			v[V ++] = convex[i];
		}
		
		if(intersects_segments(_a, _b, convex[i], convex[(i + 1) % C]))
		{
			v[V ++] = intersect(_a, _b, convex[i], convex[(i + 1) % C]);
		}
		
		if(online(_a, convex[i], _b))
		{
			v[V ++] = convex[i];
		}
		
		if(intersects_segments(_b, _c, convex[i], convex[(i + 1) % C]))
		{
			v[V ++] = intersect(_b, _c, convex[i], convex[(i + 1) % C]);
		}
		
		if(online(_b, convex[i], _c))
		{
			v[V ++] = convex[i];
		}
		
		if(intersects_segments(_c, _a, convex[i], convex[(i + 1) % C]))
		{
			v[V ++] = intersect(_c, _a, convex[i], convex[(i + 1) % C]);
		}
		
		if(online(_c, convex[i], _a))
		{
			v[V ++] = convex[i];
		}
	}
	
	make_convex();
	
	for(int i = 0; i + 1 < V; i ++)
	{
		ret += cross(v[i], v[i + 1]);
	}
	
	ret = abs(ret) * 0.5;
	
	return ret;
}

void Solve()
{
	for(int i = 0; i < A; i ++)
	{
		l.push_back(i);
	}
	
	for(now = l.begin(); 3 <= sz(l);)
	{
		if(now == l.begin()) prev = -- l.end();
		else
		{
			prev = now;
			prev --;
		}
		
		if(now == -- l.end()) next = l.begin();
		else
		{
			next = now;
			next ++;
		}
		
		int idx1 = * prev;
		int idx2 = * next;
		
		if(is_inside(idx1, idx2))
		{
			ans += overlap(a[* prev], a[* now], a[* next]);
			
			l.erase(now);
			
			now = next;
		}
		else
		{
			now ++;
			
			if(now == l.end()) now = l.begin();
		}
	}
}

void Write()
{
	printf("%.2lf\n", ans);
}

int main()
{
	Read();
	
	Solve();
	
	Write();
	
	return 0;
}
